@@ -31,13 +31,23 @@ var spacer1 = panel.addWidget("org.kde.plasma.panelspacer")
 spacer1.writeConfig("expanding", "false")
 spacer1.writeConfig("length", "10")
 
+var kicker = panel.addWidget("org.kde.plasma.kicker")
+kicker.writeConfig("customButtonImage", "/usr/share/pixmaps/ubuntustudio-logo-menu.png")
+kicker.writeConfig("showAppsByName", "true")
+kicker.currentConfigGroup = ["Shortcuts"]
+kicker.writeConfig("global", "Alt+F1")
+
 var windowtitle = panel.addWidget("org.kde.windowtitle")
 windowtitle.currentConfigGroup = ["Appearance"]
 windowtitle.writeConfig("activityIcon", "false")
 windowtitle.writeConfig("altTxt", "Ubuntu Studio")
 windowtitle.writeConfig("customIcon", "/usr/share/pixmaps/ubuntustudio-logo-menu.png")
+windowtitle.writeConfig("elidePos", "2")
+windowtitle.writeConfig("fixedLength", "190")
 windowtitle.writeConfig("isBold", "true")
+windowtitle.writeConfig("lengthKind", "1")
 windowtitle.writeConfig("midSpace", "10")
+windowtitle.writeConfig("visible", "false")
 
 var spacer2 = panel.addWidget("org.kde.plasma.panelspacer")
 spacer2.writeConfig("expanding", "false")
@@ -97,6 +107,6 @@ panel.addWidget("org.kde.plasma.systemtray")
 panel.addWidget("org.kde.plasma.digitalclock")
 panel.addWidget("org.kde.plasma.minimizeall")
 
-var spacer4 = panel.addWidget("org.kde.plasma.panelspacer")
-spacer4.writeConfig("expanding", "false")
-spacer4.writeConfig("length", "10")
+var spacer3 = panel.addWidget("org.kde.plasma.panelspacer")
+spacer3.writeConfig("expanding", "false")
+spacer3.writeConfig("length", "10")
